Learn R Programming

tidytidbits (version 0.2.3)

execute_in_pipeline: Executing language as if in a pipeline

Description

Executes the given language as if it was part of a magrittr pipeline ... %>% .language while .data is the lhs value provided to .language as parameter by magrittr.

Usage

execute_in_pipeline(.data, .language)

Arguments

.data

A data frame

.language

Language

Value

Result of the executed language

Details

Note that language is evaluated as a quosure in its captured environment. This is fine if this method is called as a secondary helper and .language is already a quosure; otherwise you may want to explicitly set the quosure's environment to your caller's env.