powered by
An object is valid if it is not null, not missing (NA), and is not an empty vector. Note that this is per se not vectorised, because a non-empty list or vector is valid as such.
invalid(x)valid(x)
valid(x)
Any object, value or NULL
logical
valid: x is not invalid
valid