A verb for a dplyr pipeline:
Groups the frame by ... in addition to the current grouping,
then calls add_summary, then returns the frame with the mutated summarising columns
in the same grouping state as it was before this function was called.
add_summary_by(.data, .language, ...)Data argument, typical "first" argument in dplyr verbs
A call to summarise(),
or another method performing equivalent aggregation (potentially wrapping summarise())
Parameters for group_by
The tibble with added columns