Executes the given language as if it was part of a magrittr pipeline
... %>% .language
while .data is the lhs value provided to .language as parameter by magrittr.
execute_in_pipeline(.data, .language)A data frame
Language
Result of the executed language
Note that language is evaluated as a quosure in its captured environment. This is fine if this method is called as a secondary helper and .language is already a quosure; otherwise you may want to explicitly set the quosure's environment to your caller's env.